# gs_usb

Python Windows/Linux CAN driver based on usbfs or WinUSB WCID for Geschwister Schneider USB/CAN devices and candleLight USB CAN interfaces.

## Getting Started

Install by ```pip install gs_usb```
